==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/almaany.md <==
## Almaany.com (SQLite3)

### General Information

| Attribute       | Value                                                                                                         |
| --------------- | ------------------------------------------------------------------------------------------------------------- |
| Name            | Almaany                                                                                                       |
| snake_case_name | almaany                                                                                                       |
| Description     | Almaany.com (SQLite3)                                                                                         |
| Extensions      |                                                                                                               |
| Read support    | Yes                                                                                                           |
| Write support   | No                                                                                                            |
| Single-file     | No                                                                                                            |
| Kind            | 🔢 binary                                                                                                      |
| Sort-on-write   | default_no                                                                                                    |
| Sort key        | (`headword_lower`)                                                                                            |
| Wiki            | ―                                                                                                             |
| Website         | [Almaany.com Arabic Dictionary - Google Play](https://play.google.com/store/apps/details?id=com.almaany.arar) |



### Dictionary Applications/Tools

| Name & Website                                                                                  | License | Platforms |
| ----------------------------------------------------------------------------------------------- | ------- | --------- |
| [Almaany.com Arabic Dictionary](https://play.google.com/store/apps/details?id=com.almaany.arar) | Unknown | Android   |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/almaany.md <==
## Almaany.com (SQLite3)

### General Information

| Attribute       | Value                                                                                                         |
| --------------- | ------------------------------------------------------------------------------------------------------------- |
| Name            | Almaany                                                                                                       |
| snake_case_name | almaany                                                                                                       |
| Description     | Almaany.com (SQLite3)                                                                                         |
| Extensions      |                                                                                                               |
| Read support    | Yes                                                                                                           |
| Write support   | No                                                                                                            |
| Single-file     | Yes                                                                                                           |
| Kind            | 🔢 binary                                                                                                      |
| Wiki            | ―                                                                                                             |
| Website         | [Almaany.com Arabic Dictionary - Google Play](https://play.google.com/store/apps/details?id=com.almaany.arar) |

### Dictionary Applications/Tools

| Name & Website                                                                                  | Source code | License | Platforms | Language |
| ----------------------------------------------------------------------------------------------- | ----------- | ------- | --------- | -------- |
| [Almaany.com Arabic Dictionary](https://play.google.com/store/apps/details?id=com.almaany.arar) | ―           | Unknown | Android   |          |
